@@ -20,6 +20,7 @@ class POI:
         self.osmMapa = osmMapa
         self.CONFIG = CONFIG
         self.file = "/home/user/yosmapaPOI.xml"
+        self.ico_poi = gdk.pixbuf_new_from_file("./plugins/POI.png")
         self.poi = []
         self.poi_images = []
         print "__init__ POI"
@@ -72,9 +73,8 @@ class POI:
     def poi_rebuild(self):
         self.clean_layer()
 
-        for pa in self.poi:
-            i = gdk.pixbuf_new_from_file("./plugins/POI.png")
-            self.poi_images.append( self.osmMapa.osm.image_add( float(pa[2]), float(pa[3]), i ) )
+        for pa in self.poi:            
+            self.poi_images.append( self.osmMapa.osm.image_add( float(pa[2]), float(pa[3]), self.ico_poi ) )
             print "POI - > add point on map"
 
     def clean_layer(self):
@@ -167,12 +167,9 @@ class POI:
             cr = gdkdrawable.cairo_create()
 
             for p in self.poi:
-                lt = p[2]
-                ln = p[3]
-                #print "lt:",t_lt,t_ln,"\t c:",lt,ln,"\tb:",b_lt,b_ln
-                if t_ln < ln and b_ln > ln and t_lt > lt and b_lt < lt:
-                    x,y = self.osmMapa.osm.geographic_to_screen(lt,ln)
-                    self.osmMapa.draw_cloud( cr, x,y, p[1] )
+                if t_ln < p[3] and b_ln > p[3]:
+                    if t_lt > p[2] and b_lt < p[2]:
+                        self.osmMapa.draw_cloud_byll( cr, p[2], p[3], p[1] )
 
 
     def do_render(self, gpsmap):
