@@ -327,8 +327,7 @@ class nominatim_geonames:
 
                 #print "lt:",t_lt,t_ln,"\t c:",lt,ln,"\tb:",b_lt,b_ln
                 if t_ln < ln and b_ln > ln and t_lt > lt and b_lt < lt:
-                    x,y = self.osmMapa.osm.geographic_to_screen(lt,ln)
-                    self.osmMapa.draw_cloud( cr, x,y, p[3])
+                    self.osmMapa.draw_cloud_byll( cr, lt,ln, p[3])
 
     def do_render(self, gpsmap):
         pass
